@@ -3,8 +3,6 @@ from functools import lru_cache
 
 import requests
 
-from api_manager.settings import ALMS_IDENTITY_SERVER, ALMS_USER, LABS_API, LABS_USER
-
 
 @lru_cache(maxsize=None)
 def get_alms_token(user=None):
@@ -12,6 +10,8 @@ def get_alms_token(user=None):
     :param user:
     :return:
     """
+    from api_manager.settings import ALMS_IDENTITY_SERVER, ALMS_USER  # no qa
+
     if isinstance(user, str):
         user = json.loads(user)
 
@@ -22,6 +22,8 @@ def get_alms_token(user=None):
 
 @lru_cache(maxsize=None)
 def get_labs_token(user=None):
+    from api_manager.settings import LABS_API, LABS_USER  # no qa
+
     if isinstance(user, str):
         user = json.loads(user)
 
